unit fNutella;

// the GnutViewer Project's main form

(****************************************************************
Copyright (C)2000, Michael Ax. Created 2000. All rights reserved.
License to copy, use also for making and using derivative works
of this software is granted provided that that such works are
identified as "derived from the GnutViewer project" in all material
mentioning or referencing the derived work. Michael Ax makes no
representations concerning either the merchantability of this software
or the suitability of this software for any particular purpose. It is
provided "as is" without express or implied warranty of any kind.
These notices must be retained in this documentation and/or software.
*****************************************************************)

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, gNutella, Buttons, ExtCtrls, gNutFrame, gNfrConnections,
  gNfrHosts, gNfrLog, gNfrServe, gNfrSearch, ComCtrls, gNfrServers,
  gNfrPush;

type
  TForm1 = class(TForm)
    GnuTella: TGnuTellaTrans;
    PageControl1: TPageControl;
    tsConfig: TTabSheet;
    tsLog: TTabSheet;
    Memo1: TMemo;
    Button4: TButton;
    SpeedButton1: TSpeedButton;
    tsConnectionsFr: TTabSheet;
    tsHostsFr: TTabSheet;
    gNutHosts: TgNutHosts;
    tsSearchFr: TTabSheet;
    gNutSearch: TgNutSearch;
    tsServeFr: TTabSheet;
    gNutServe: TgNutServe;
    tsLogFr: TTabSheet;
    tsServers: TTabSheet;
    gNutServers: TgNutServers;
    gNutLog: TgNutLog;
    tsPush: TTabSheet;
    gNutPush1: TgNutPush;
    gNutConnections: TgNutConnections;
    procedure GnuTellaInitResponse(const HostIP: String;HostPort: Word; FileCnt, FileSize: Integer);
    procedure SpeedButton1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Button4Click(Sender: TObject);
  private
    procedure Entering(const Sender,aText: String);
  public
    end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

{
  public
    procedure ConnectNewHost(const Host : string);
    procedure ClearGTNStats;
    procedure SendInitToAll;
    procedure SendOneInit(Socket : TCustomWinSocket);
    procedure BeginSearch(const Query : string; MinSpeed : WORD);
    procedure Listen;
    procedure CancelListen;

    property MessagesIn: integer read FMessagesIn;
    property SearchesIn: integer read FSearchesIn;
    property GTNHosts: integer read FGTNHosts;
    property GTNFiles: integer read FGTNFiles;
    property GTNSize: integer read FGTNSize;
    property GTNAvgPing: integer read FGTNAvgPing;
    property ConnectionCount: integer read GetConnectionCount;
    property SocketCount: integer read GetSocketCount;
    property LocalFileCount: integer read FLocalFileCount;
    property LocalFileSize: integer read FLocalFileSize;
  published
    property ConnectionSpeed: integer read FConnectionSpeed write FConnectionSpeed;
    property ListenPort: integer read FListenPort write SetListenPort;
    property LocalIP: string read FLocalIP write FLocalIP;
    property MyTTL: BYTE read FMyTTL write FMyTTL;
    property MaxTTL: BYTE read FMaxTTL write FMaxTTL;
    property SendInitOnConnect: boolean read FSendInitOnConnect write FSendInitOnConnect;

    property OnCatchHost: TStringEvent read FOnCatchHost write FOnCatchHost;
    property OnClientConnected: TClientSockEvent read FOnClientConnected
      write FOnClientConnected;
    property OnClientCreated: TClientSockEvent read FOnClientCreated write FOnClientCreated;
    property OnClientProtocolConnect: TClientSockEvent read FOnClientProtocolConnect write FOnClientProtocolConnect;
    property OnInitResponse: TInitRespEvent read FOnInitResponse write FOnInitResponse;
    property OnLogStatus: TStringEvent read FOnLogStatus write FOnLogStatus;
    property OnSearchReq: TSearchReqEvent read FOnSearchReq write FOnSearchReq;
    property OnSrchRespBegin: TSrchRespBeginEvent read FOnSrchRespBegin write FOnSrchRespBegin;
    property OnSrchRespEnd: TSrchRespEndEvent read FOnSrchRespEnd write FOnSrchRespEnd;
    property OnSrchRespItem: TSrchRespItemEvent read FOnSrchRespItem write FOnSrchRespItem;
    property OnPushRequest: TNotifyEvent read FOnPushRequest write FOnPushRequest;
    property OnClientDisconnect: TClientSockEvent read FOnClientDisconnect write FOnClientDisconnect;
    end;

}

//------------------------------------------------------------------------------

procedure TForm1.FormCreate(Sender: TObject);
begin
  gNutHosts.Init(GnuTella);
  gNutPush1.Init(GnuTella);
  gNutServers.Init(GnuTella);
  gNutConnections.Servers:= gNutServers.Memo1.Lines;
  gNutConnections.Init(GnuTella);
  gNutServe.Init(GnuTella);
  gNutSearch.Init(GnuTella);
  gNutLog.Init(GnuTella);
  memo1.lines.clear;
end;

//------------------------------------------------------------------------------

procedure TForm1.Entering(const Sender,aText: String);
begin
  with memo1.lines do begin
    add(Sender);
    if Count>nLines then
      Delete(0);
    if aText<>'' then begin
      Add('  ['+aText);
      if Count>nLines then
        Delete(0);
      end;
    end;
end;

//------------------------------------------------------------------------------

procedure TForm1.GnuTellaInitResponse(const HostIP: String; HostPort: Word; FileCnt, FileSize: Integer);
begin
  Entering('init response: '+hostip+':'+inttostr(HostPort)+' ['+inttostr(FileCnt)+','+inttostr(FileSize)+']','');
end;

//------------------------------------------------------------------------------

procedure TForm1.SpeedButton1Click(Sender: TObject);
begin
  with GnuTella, tSpeedButton(Sender) do begin
    //Down:= not Down;
    if Down then
      Listen
    else
      CancelListen;
    end;
end;

//------------------------------------------------------------------------------

procedure TForm1.Button4Click(Sender: TObject);
begin
  with GnuTella do
    SendInitToAll;
end;

end.
